package
Version:
v0.0.0-...-2df46c3
Opens a new window with list of versions in this module.
Published: Feb 22, 2018
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func AppendHookOnUpdate(f func() error)
AppendHookOnUpdate appends a hook function that is run before the main update function
every frame.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.